@@ -495,31 +495,27 @@ sub create_bootstrap_header_source {
 
 EOS
   
-  my $no_precompile = $config_exe->no_precompile;
-  
-  unless ($no_precompile) {
-    $source .= "// precompile functions declaration\n";
-    for my $module_name (@$module_names) {
-      my $precompile_method_names = $self->runtime->get_method_names($module_name, 'precompile');
-      for my $method_name (@$precompile_method_names) {
-        my $method_cname = $module_name;
-        $method_cname =~ s/::/__/g;
-        $source .= <<"EOS";
+  $source .= "// precompile functions declaration\n";
+  for my $module_name (@$module_names) {
+    my $precompile_method_names = $self->runtime->get_method_names($module_name, 'precompile');
+    for my $method_name (@$precompile_method_names) {
+      my $method_cname = $module_name;
+      $method_cname =~ s/::/__/g;
+      $source .= <<"EOS";
 int32_t SPVMPRECOMPILE__${method_cname}__$method_name(SPVM_ENV* env, SPVM_VALUE* stack);
 EOS
-      }
     }
+  }
 
-    $source .= "static int32_t* SPVM_BOOTSTRAP_create_bootstrap_set_precompile_method_addresses(SPVM_ENV* env);\n";
+  $source .= "static int32_t* SPVM_BOOTSTRAP_create_bootstrap_set_precompile_method_addresses(SPVM_ENV* env);\n";
 
-    $source .= <<"EOS";
+  $source .= <<"EOS";
 static int32_t* SPVM_BOOTSTRAP_set_precompile_method_address(SPVM_ENV* env, const char* module_name, const char* method_name, void* precompile_address) {
-  void* module_basic_type = env->api->runtime->get_basic_type_by_name(env->runtime, module_name);
-  void* method = env->api->runtime->get_method_by_name(env->runtime, module_basic_type, method_name);
-  env->api->runtime->set_precompile_method_address(env->runtime, method, precompile_address);
+void* module_basic_type = env->api->runtime->get_basic_type_by_name(env->runtime, module_name);
+void* method = env->api->runtime->get_method_by_name(env->runtime, module_basic_type, method_name);
+env->api->runtime->set_precompile_method_address(env->runtime, method, precompile_address);
 }
 EOS
-  }
   
   $source .= "// native functions declaration\n";
   for my $method_cname (@$module_names) {
@@ -705,10 +701,7 @@ sub create_bootstrap_new_env_prepared_func_source {
   my $set_precompile_method_addresses_source = '';
   
   my $config_exe = $self->config;
-  my $no_precompile = $config_exe->no_precompile;
-  unless ($no_precompile) {
-    $set_precompile_method_addresses_source = "SPVM_BOOTSTRAP_create_bootstrap_set_precompile_method_addresses(env);";
-  }
+  $set_precompile_method_addresses_source = "SPVM_BOOTSTRAP_create_bootstrap_set_precompile_method_addresses(env);";
   $source .= <<"EOS";
 SPVM_ENV* SPVM_NATIVE_new_env_prepared() {
 EOS
@@ -719,7 +712,7 @@ EOS
   SPVM_ENV* env = SPVM_NATIVE_new_env_raw();
 
   // New runtime
-  void* runtime = env->api->runtime->new_object(env);
+  void* runtime = env->api->runtime->new_instance();
   
   // Runtime allocator
   void* runtime_allocator = env->api->runtime->get_allocator(runtime);
@@ -853,10 +846,7 @@ sub create_bootstrap_source {
 
     # Set precompile method addresses function
     my $config_exe = $self->config;
-    my $no_precompile = $config_exe->no_precompile;
-    unless ($no_precompile) {
-      $bootstrap_source .= $self->create_bootstrap_set_precompile_method_addresses_func_source;
-    }
+    $bootstrap_source .= $self->create_bootstrap_set_precompile_method_addresses_func_source;
 
     # Set native method addresses function
     $bootstrap_source .= $self->create_bootstrap_set_native_method_addresses_func_source;
@@ -928,14 +918,8 @@ sub compile_spvm_core_source_files {
   my $builder_src_dir = "$builder_dir/src";
   
   # SPVM runtime source files
-  my $no_compiler_api = $config_exe->no_compiler_api;
   my $spvm_runtime_src_base_names;
-  if ($no_compiler_api) {
-    $spvm_runtime_src_base_names = SPVM::Builder::Util::get_spvm_core_common_source_file_names();
-  }
-  else {
-    $spvm_runtime_src_base_names = SPVM::Builder::Util::get_spvm_core_source_file_names();
-  }
+  $spvm_runtime_src_base_names = SPVM::Builder::Util::get_spvm_core_source_file_names();
   my @spvm_core_source_files = map { "$builder_src_dir/$_" } @$spvm_runtime_src_base_names;
   
   # Object dir
@@ -948,10 +932,6 @@ sub compile_spvm_core_source_files {
     confess "The config_spvm_core field in the SPVM::Builder::Config module must be defined";
   }
   
-  if ($no_compiler_api) {
-    $config->add_ccflag('-DSPVM_NO_COMPILER_API');
-  }
-  
   # Compile source files
   my $object_files = [];
   for my $src_file (@spvm_core_source_files) {
@@ -976,10 +956,6 @@ sub compile_module_precompile_source_file {
 
   my $config_exe = $self->config;
   
-  my $no_precompile = $config_exe->no_precompile;
-  
-  return [] if $no_precompile;
-
   # Builer
   my $builder = $self->builder;
   
@@ -1000,9 +976,9 @@ sub compile_module_precompile_source_file {
     mkpath $build_src_dir;
     
     my $module_file = $self->runtime->get_module_file($module_name);
-    my $precompile_source = $self->runtime->build_precompile_source($module_name);
+    my $precompile_source = $self->runtime->build_precompile_module_source($module_name);
     
-    $builder_cc->build_precompile_source_file(
+    $builder_cc->build_precompile_module_source_file(
       $module_name,
       {
         output_dir => $build_src_dir,
