@@ -17,51 +17,6 @@ use File::Find 'find';
 # SPVM::Builder::Util is used from Makefile.PL
 # so this class must be wrote as pure perl script, not contain XS functions.
 
-sub get_spvm_core_files {
-  
-  my @spvm_core_files;
-  if (my $builder_loaded_file = $INC{'SPVM/Builder/Util.pm'}) {
-    my $builder_loaded_dir = $builder_loaded_file;
-    $builder_loaded_dir =~ s|[/\\]SPVM/Builder/Util\.pm$||;
-    
-    # SPVM::Builder module files
-    my $spvm_builder_module_file_names = &get_spvm_builder_module_file_names();
-    for my $spvm_builder_module_file_name (@$spvm_builder_module_file_names) {
-      my $module_file = "$builder_loaded_dir/$spvm_builder_module_file_name";
-      unless (-f $module_file) {
-        confess "Can't find $module_file";
-      }
-      push @spvm_core_files, $module_file;
-    }
-    
-    # SPVM core header files
-    my $spvm_core_header_file_names = &get_spvm_core_header_file_names();
-    for my $spvm_core_header_file_name (@$spvm_core_header_file_names) {
-      my $spvm_core_header_file = "$builder_loaded_dir/SPVM/Builder/include/$spvm_core_header_file_name";
-      unless (-f $spvm_core_header_file) {
-        confess "Can't find $spvm_core_header_file";
-      }
-      push @spvm_core_files, $spvm_core_header_file;
-    }
-    
-    # SPVM core source files
-    my $spvm_core_source_file_names  = &get_spvm_core_source_file_names();
-    for my $spvm_core_source_file_name (@$spvm_core_source_file_names) {
-      my $spvm_core_source_file = "$builder_loaded_dir/SPVM/Builder/src/$spvm_core_source_file_name";
-      unless (-f $spvm_core_source_file) {
-        confess "Can't find $spvm_core_source_file";
-      }
-      push @spvm_core_files, $spvm_core_source_file;
-    }
-  }
-  
-  unless (@spvm_core_files) {
-    confess "[Unexpected Error]SPVM source files are not found";
-  }
-  
-  return \@spvm_core_files;
-}
-
 sub need_generate {
   my ($opt) = @_;
   
@@ -70,14 +25,14 @@ sub need_generate {
   my $output_file = $opt->{output_file};
   
   # SPVM::Builder classes
-  my @spvm_core_files = @{&get_spvm_core_files};
+  my $spvm_dependent_files = &get_spvm_dependent_files;
   
-  my $spvm_core_files_mtime_max;
-  $spvm_core_files_mtime_max = 0;
-  for my $spvm_core_file (@spvm_core_files) {
+  my $spvm_dependent_files_mtime_max;
+  $spvm_dependent_files_mtime_max = 0;
+  for my $spvm_core_file (@$spvm_dependent_files) {
     my $spvm_core_file_mtime = (stat($spvm_core_file))[9];
-    if ($spvm_core_file_mtime > $spvm_core_files_mtime_max) {
-      $spvm_core_files_mtime_max = $spvm_core_file_mtime;
+    if ($spvm_core_file_mtime > $spvm_dependent_files_mtime_max) {
+      $spvm_dependent_files_mtime_max = $spvm_core_file_mtime;
     }
   }
 
@@ -104,9 +59,9 @@ sub need_generate {
       if ($exists_input_file_at_least_one) {
         my $output_file_mtime = (stat($output_file))[9];
         
-        if (defined $spvm_core_files_mtime_max) {
-          if ($spvm_core_files_mtime_max > $input_files_mtime_max) {
-            $input_files_mtime_max = $spvm_core_files_mtime_max;
+        if (defined $spvm_dependent_files_mtime_max) {
+          if ($spvm_dependent_files_mtime_max > $input_files_mtime_max) {
+            $input_files_mtime_max = $spvm_dependent_files_mtime_max;
           }
         }
         
@@ -377,100 +332,95 @@ sub create_make_rule {
   return $make_rule;
 }
 
-sub get_spvm_builder_module_file_names {
+sub get_spvm_dependent_files {
+  
+  my @spvm_dependent_files;
+  if (my $builder_loaded_file = $INC{'SPVM/Builder/Util.pm'}) {
+    my $builder_loaded_dir = $builder_loaded_file;
+    $builder_loaded_dir =~ s|[/\\]SPVM/Builder/Util\.pm$||;
+    
+    # SPVM::Builder module files
+    my $spvm_core_perl_module_file_names = &get_spvm_core_perl_module_file_names();
+    for my $spvm_core_perl_module_file_name (@$spvm_core_perl_module_file_names) {
+      my $spvm_core_perl_module_file = "$builder_loaded_dir/$spvm_core_perl_module_file_name";
+      unless (-f $spvm_core_perl_module_file) {
+        confess "Can't find $spvm_core_perl_module_file";
+      }
+      push @spvm_dependent_files, $spvm_core_perl_module_file;
+    }
+    
+    # SPVM core header files
+    my $spvm_core_header_file_names = &get_spvm_core_header_file_names();
+    for my $spvm_core_header_file_name (@$spvm_core_header_file_names) {
+      my $spvm_core_header_file = "$builder_loaded_dir/SPVM/Builder/include/$spvm_core_header_file_name";
+      unless (-f $spvm_core_header_file) {
+        confess "Can't find $spvm_core_header_file";
+      }
+      push @spvm_dependent_files, $spvm_core_header_file;
+    }
+    
+    # SPVM core source files
+    my $spvm_core_source_file_names  = &get_spvm_core_source_file_names();
+    for my $spvm_core_source_file_name (@$spvm_core_source_file_names) {
+      my $spvm_core_source_file = "$builder_loaded_dir/SPVM/Builder/src/$spvm_core_source_file_name";
+      unless (-f $spvm_core_source_file) {
+        confess "Can't find $spvm_core_source_file";
+      }
+      push @spvm_dependent_files, $spvm_core_source_file;
+    }
+    
+    # SPVM Compiler and Runtime module file names
+    my $spvm_compiler_and_runtime_module_file_names = &get_spvm_core_perl_module_file_names();
+    for my $spvm_compiler_and_runtime_module_file_name (@$spvm_compiler_and_runtime_module_file_names) {
+      my $spvm_compiler_and_runtime_module_file = "$builder_loaded_dir/$spvm_compiler_and_runtime_module_file_name";
+      unless (-f $spvm_compiler_and_runtime_module_file) {
+        confess "Can't find $spvm_compiler_and_runtime_module_file";
+      }
+      push @spvm_dependent_files, $spvm_compiler_and_runtime_module_file;
+    }
+  }
+  
+  unless (@spvm_dependent_files) {
+    confess "[Unexpected Error]SPVM dependent files are not found";
+  }
+  
+  return \@spvm_dependent_files;
+}
+
+sub get_spvm_core_perl_module_file_names {
   my @spvm_builder_module_file_names = qw(
+    SPVM/BlessedObject/Array.pm
+    SPVM/BlessedObject/Class.pm
+    SPVM/BlessedObject.pm
+    SPVM/BlessedObject/String.pm
     SPVM/Builder/API.pm
     SPVM/Builder/CC.pm
     SPVM/Builder/CompileInfo.pm
+    SPVM/Builder/Compiler.pm
     SPVM/Builder/Config/Exe.pm
     SPVM/Builder/Config.pm
+    SPVM/Builder/Env.pm
     SPVM/Builder/Exe.pm
     SPVM/Builder/LibInfo.pm
     SPVM/Builder/LinkInfo.pm
     SPVM/Builder/ObjectFileInfo.pm
     SPVM/Builder.pm
     SPVM/Builder/Resource.pm
+    SPVM/Builder/Runtime.pm
+    SPVM/Builder/Stack.pm
     SPVM/Builder/Util/API.pm
     SPVM/Builder/Util.pm
+    SPVM/Document/ExchangeAPI.pm
+    SPVM/ExchangeAPI/Class.pm
+    SPVM/ExchangeAPI/Error.pm
+    SPVM/ExchangeAPI.pm
+    SPVM/Global.pm
+    SPVM.pm
   );
   
   return \@spvm_builder_module_file_names;
 }
 
-sub get_spvm_core_source_file_names {
-  
-  my @spvm_core_source_file_names = qw(
-    spvm_allocator.c
-    spvm_allow.c
-    spvm_api_allocator.c
-    spvm_api.c
-    spvm_api_compiler.c
-    spvm_api_precompile.c
-    spvm_api_runtime.c
-    spvm_api_string_buffer.c
-    spvm_array_field_access.c
-    spvm_attribute.c
-    spvm_basic_type.c
-    spvm_block.c
-    spvm_call_method.c
-    spvm_case_info.c
-    spvm_class_var_access.c
-    spvm_class_var.c
-    spvm_compiler.c
-    spvm_constant.c
-    spvm_string.c
-    spvm_dumper.c
-    spvm_field_access.c
-    spvm_field.c
-    spvm_hash.c
-    spvm_interface.c
-    spvm_list.c
-    spvm_method.c
-    spvm_native.c
-    spvm_op.c
-    spvm_check.c
-    spvm_opcode_list.c
-    spvm_opcode_builder.c
-    spvm_opcode.c
-    spvm_precompile.c
-    spvm_runtime.c
-    spvm_strerror.c
-    spvm_string_buffer.c
-    spvm_switch_info.c
-    spvm_toke.c
-    spvm_type.c
-    spvm_use.c
-    spvm_var.c
-    spvm_var_decl.c
-    spvm_vm.c
-    spvm_yacc.c
-    spvm_yacc_util.c
-  );
-  
-  return \@spvm_core_source_file_names;
-}
-
-sub get_spvm_core_common_source_file_names {
-  
-  my @spvm_core_source_file_names = qw(
-    spvm_allocator.c
-    spvm_api_allocator.c
-    spvm_api.c
-    spvm_api_runtime.c
-    spvm_api_string_buffer.c
-    spvm_hash.c
-    spvm_list.c
-    spvm_native.c
-    spvm_opcode.c
-    spvm_runtime.c
-    spvm_strerror.c
-    spvm_string_buffer.c
-    spvm_vm.c
-  );
-  
-  return \@spvm_core_source_file_names;
-}
-
 sub get_spvm_core_header_file_names {
   
   my @spvm_core_header_file_names = qw(
@@ -479,7 +429,6 @@ sub get_spvm_core_header_file_names {
     spvm_api_allocator.h
     spvm_api_compiler.h
     spvm_api.h
-    spvm_api_precompile.h
     spvm_api_runtime.h
     spvm_api_string_buffer.h
     spvm_array_field_access.h
@@ -501,6 +450,7 @@ sub get_spvm_core_header_file_names {
     spvm_interface.h
     spvm_list.h
     spvm_method.h
+    spvm_module_file.h
     spvm_native.h
     spvm_object.h
     spvm_check.h
@@ -535,6 +485,74 @@ sub get_spvm_core_header_file_names {
   return \@spvm_core_header_file_names;
 }
 
+sub get_spvm_core_source_file_names {
+  
+  my @spvm_core_source_file_names = qw(
+    spvm_allocator.c
+    spvm_allow.c
+    spvm_api_allocator.c
+    spvm_api.c
+    spvm_api_compiler.c
+    spvm_api_runtime.c
+    spvm_api_string_buffer.c
+    spvm_array_field_access.c
+    spvm_attribute.c
+    spvm_basic_type.c
+    spvm_block.c
+    spvm_call_method.c
+    spvm_case_info.c
+    spvm_check.c
+    spvm_class_var_access.c
+    spvm_class_var.c
+    spvm_compiler.c
+    spvm_constant.c
+    spvm_dumper.c
+    spvm_field_access.c
+    spvm_field.c
+    spvm_hash.c
+    spvm_interface.c
+    spvm_list.c
+    spvm_method.c
+    spvm_module_file.c
+    spvm_native.c
+    spvm_op.c
+    spvm_opcode_builder.c
+    spvm_opcode.c
+    spvm_opcode_list.c
+    spvm_precompile.c
+    spvm_runtime.c
+    spvm_strerror.c
+    spvm_string_buffer.c
+    spvm_string.c
+    spvm_switch_info.c
+    spvm_toke.c
+    spvm_type.c
+    spvm_use.c
+    spvm_var.c
+    spvm_var_decl.c
+    spvm_vm.c
+    spvm_yacc.c
+    spvm_yacc_util.c
+  );
+
+  return \@spvm_core_source_file_names;
+}
+
+sub get_spvm_compiler_and_runtime_module_file_names {
+  my @spvm_compiler_and_runtime_module_file_names = qw(
+    SPVM/Compiler.c
+    SPVM/Compiler.spvm
+    SPVM/Env.c
+    SPVM/Env.spvm
+    SPVM/Runtime.c
+    SPVM/Runtime.spvm
+    SPVM/Stack.c
+    SPVM/Stack.spvm
+  );
+  
+  return \@spvm_compiler_and_runtime_module_file_names;
+}
+
 sub get_config_file_from_module_name {
   my ($module_name, $mode) = @_;
   
