@@ -10,8 +10,8 @@
 SPVM_ENV_RUNTIME* SPVM_API_RUNTIME_new_env();
 
 // Runtime
-SPVM_RUNTIME* SPVM_API_RUNTIME_new_object();
-void SPVM_API_RUNTIME_free_object(SPVM_RUNTIME* runtime);
+SPVM_RUNTIME* SPVM_API_RUNTIME_new_instance();
+void SPVM_API_RUNTIME_free_instance(SPVM_RUNTIME* runtime);
 void SPVM_API_RUNTIME_build(SPVM_RUNTIME* runtime, int32_t* runtime_codes);
 
 // Runtime codes
@@ -123,4 +123,8 @@ int32_t SPVM_API_RUNTIME_can_assign(SPVM_RUNTIME* runtime, SPVM_RUNTIME_BASIC_TY
 // Allocation
 SPVM_ALLOCATOR* SPVM_API_RUNTIME_get_allocator(SPVM_RUNTIME* runtime);
 
+void SPVM_API_PRECOMPILE_build_precompile_module_source(SPVM_RUNTIME* runtime, SPVM_STRING_BUFFER* string_buffer, const char* module_name);
+
+void SPVM_API_PRECOMPILE_build_precompile_method_source(SPVM_RUNTIME* runtime, SPVM_STRING_BUFFER* string_buffer, const char* module_name, const char* method_name);
+
 #endif
