@@ -33,7 +33,7 @@ struct spvm_compiler {
   const char* cur_rel_file;
   
   // Current parsed basic type name
-  const char* cur_rel_file_basic_type_name;
+  const char* cur_rel_file_module_name;
   
   // Current parsed source
   char* cur_source;
@@ -93,13 +93,13 @@ struct spvm_compiler {
   SPVM_LIST* error_messages;
   
   // Module source symtable
-  SPVM_HASH* module_source_symtable;
+  SPVM_HASH* module_file_symtable;
   
   // String symtable
   SPVM_HASH* string_symtable;
   
   // Fail load class symtable
-  SPVM_HASH* if_require_not_found_basic_type_name_symtable;
+  SPVM_HASH* if_require_not_found_module_name_symtable;
   
   // Basic types
   SPVM_LIST* basic_types;
@@ -116,7 +116,8 @@ struct spvm_compiler {
 
 SPVM_COMPILER* SPVM_COMPILER_new();
 void SPVM_COMPILER_free(SPVM_COMPILER* compiler);
-void SPVM_COMPILER_add_source(SPVM_COMPILER* compiler, const char* basic_type_name, const char* source, int32_t length);
+SPVM_MODULE_FILE* SPVM_COMPILER_get_module_file(SPVM_COMPILER* compiler, const char* module_name);
+void SPVM_COMPILER_add_module_file(SPVM_COMPILER* compiler, const char* module_name, SPVM_MODULE_FILE* module_file);
 void SPVM_COMPILER_add_basic_type_core(SPVM_COMPILER* compiler, int32_t basic_type_id, int32_t basic_type_category);
 SPVM_BASIC_TYPE* SPVM_COMPILER_add_basic_type(SPVM_COMPILER* compiler, const char* basic_type_name);
 void SPVM_COMPILER_add_basic_types(SPVM_COMPILER* compiler);
