@@ -9,7 +9,7 @@
 #include <string.h>
 #include <stdarg.h>
 
-#define SPVM_NATIVE_VERSION_NUMBER 0.989018
+#define SPVM_NATIVE_VERSION_NUMBER 0.989019
 
 #define SPVM_NATIVE_CREATE_VERSION_STRING_STRINGIFY(x) #x
 
@@ -29,9 +29,6 @@ typedef struct spvm_env_compiler SPVM_ENV_COMPILER;
 struct spvm_env_runtime;
 typedef struct spvm_env_runtime SPVM_ENV_RUNTIME;
 
-struct spvm_env_precompile;
-typedef struct spvm_env_precompile SPVM_ENV_PRECOMPILE;
-
 struct spvm_env_string_buffer;
 typedef struct spvm_env_string_buffer SPVM_ENV_STRING_BUFFER;
 
@@ -322,8 +319,8 @@ struct spvm_env {
 };
 
 struct spvm_env_runtime {
-  void* (*new_object)();
-  void (*free_object)(void* runtime);
+  void* (*new_instance)(void);
+  void (*free_instance)(void* runtime);
   int32_t* (*get_opcodes)(void* runtime);
   void* reserved3;
   int32_t* (*get_runtime_codes)(void* runtime);
@@ -457,11 +454,13 @@ struct spvm_env_runtime {
   void* (*get_arg)(void* runtime, void* method, int32_t arg_index);
   void* (*get_basic_type_by_name)(void* runtime, const char* basic_type_name);
   void* (*get_basic_type_anon_basic_type)(void* runtime, void* basic_type, int32_t anon_basic_type_index);
+  void (*build_precompile_module_source)(void* runtime, void* string_buffer, const char* module_name);
+  void (*build_precompile_method_source)(void* runtime, void* string_buffer, const char* module_name, const char* method_name);
 };
 
 struct spvm_env_compiler {
-  void* (*new_object)();
-  void (*free_object)(void* compiler);
+  void* (*new_instance)(void);
+  void (*free_instance)(void* compiler);
   void (*set_start_line)(void* compiler, int32_t start_line);
   int32_t (*get_start_line)(void* compiler);
   void (*set_start_file)(void* compiler, const char* start_file);
@@ -476,18 +475,30 @@ struct spvm_env_compiler {
   void (*clear_include_dirs)(void* compiler);
 };
 
-struct spvm_env_precompile {
-  void* (*new_object)();
-  void (*free_object)(void* precompile);
-  void (*set_runtime)(void* precompile, void* runtime);
-  void* (*get_runtime)(void* precompile);
-  void (*build_source)(void* precompile, void* string_buffer, const char* basic_type_name);
-  void (*build_method_source)(void* precompile, void* string_buffer, const char* basic_type_name, const char* method_name);
-};
-
 SPVM_ENV* SPVM_NATIVE_new_env_raw();
 SPVM_ENV* SPVM_NATIVE_new_env_prepared();
 
+struct spvm_env_allocator {
+  void* (*new_instance)(void);
+  void (*free_instance)(void* allocator);
+};
+
+struct spvm_env_string_buffer {
+  void* (*new_instance)(void* allocator, int32_t capacity);
+  void (*free_instance)(void* string_buffer);
+  const char* (*get_string)(void* string_buffer);
+  int32_t (*get_length)(void* string_buffer);
+};
+
+struct spvm_env_api {
+  SPVM_ENV_ALLOCATOR* allocator;
+  SPVM_ENV_STRING_BUFFER* string_buffer;
+  SPVM_ENV_COMPILER* compiler;
+  SPVM_ENV_RUNTIME* runtime;
+};
+
+#define spvm_warn(format, ...) fprintf(stderr, format "\n", ##__VA_ARGS__)
+
 enum {
   SPVM_NATIVE_C_BASIC_TYPE_ID_UNKNOWN,
   SPVM_NATIVE_C_BASIC_TYPE_ID_UNDEF,
@@ -531,26 +542,4 @@ enum {
   SPVM_NATIVE_C_TYPE_FLAG_MUTABLE = 2,
 };
 
-struct spvm_env_allocator {
-  void* (*new_object)();
-  void (*free_object)(void* allocator);
-};
-
-struct spvm_env_string_buffer {
-  void* (*new_object)();
-  void (*free_object)(void* string_buffer);
-  const char* (*get_value)(void* string_buffer);
-  int32_t (*get_length)(void* string_buffer);
-};
-
-struct spvm_env_api {
-  SPVM_ENV_ALLOCATOR* allocator;
-  SPVM_ENV_STRING_BUFFER* string_buffer;
-  SPVM_ENV_COMPILER* compiler;
-  SPVM_ENV_PRECOMPILE* precompile;
-  SPVM_ENV_RUNTIME* runtime;
-};
-
-#define spvm_warn(format, ...) fprintf(stderr, format "\n", ##__VA_ARGS__)
-
 #endif
