@@ -12,8 +12,8 @@ SPVM_ENV_ALLOCATOR* SPVM_API_ALLOCATOR_new_env() {
   
   // Env Allocator
   void* env_allocator_init[]  = {
-    SPVM_API_ALLOCATOR_new_object,
-    SPVM_API_ALLOCATOR_free_object,
+    SPVM_API_ALLOCATOR_new_instance,
+    SPVM_API_ALLOCATOR_free_instance,
   };
   SPVM_ENV_ALLOCATOR* env_allocator = calloc(1, sizeof(env_allocator_init));
   memcpy(env_allocator, env_allocator_init, sizeof(env_allocator_init));
@@ -21,12 +21,12 @@ SPVM_ENV_ALLOCATOR* SPVM_API_ALLOCATOR_new_env() {
   return env_allocator;
 }
 
-SPVM_ALLOCATOR* SPVM_API_ALLOCATOR_new_object() {
+SPVM_ALLOCATOR* SPVM_API_ALLOCATOR_new_instance() {
   SPVM_ALLOCATOR* allocator = SPVM_ALLOCATOR_new();
 
   return allocator;
 }
 
-void SPVM_API_ALLOCATOR_free_object(SPVM_ALLOCATOR* allocator) {
+void SPVM_API_ALLOCATOR_free_instance(SPVM_ALLOCATOR* allocator) {
   SPVM_ALLOCATOR_free(allocator);
 }
