@@ -29,7 +29,7 @@
 #include "spvm_runtime_string.h"
 #include "spvm_api_runtime.h"
 #include "spvm_runtime_arg.h"
-
+#include "spvm_precompile.h"
 
 
 
@@ -97,8 +97,8 @@
 SPVM_ENV_RUNTIME* SPVM_API_RUNTIME_new_env() {
   
   void* env_runtime_init[]  = {
-    SPVM_API_RUNTIME_new_object,
-    SPVM_API_RUNTIME_free_object,
+    SPVM_API_RUNTIME_new_instance,
+    SPVM_API_RUNTIME_free_instance,
     SPVM_API_RUNTIME_get_opcodes,
     NULL, // reserved3
     SPVM_API_RUNTIME_get_runtime_codes,
@@ -232,6 +232,8 @@ SPVM_ENV_RUNTIME* SPVM_API_RUNTIME_new_env() {
     SPVM_API_RUNTIME_get_arg,
     SPVM_API_RUNTIME_get_basic_type_by_name,
     SPVM_API_RUNTIME_get_basic_type_anon_basic_type,
+    SPVM_API_PRECOMPILE_build_precompile_module_source,
+    SPVM_API_PRECOMPILE_build_precompile_method_source,
   };
   SPVM_ENV_RUNTIME* env_runtime = calloc(1, sizeof(env_runtime_init));
   memcpy(env_runtime, env_runtime_init, sizeof(env_runtime_init));
@@ -239,13 +241,13 @@ SPVM_ENV_RUNTIME* SPVM_API_RUNTIME_new_env() {
   return env_runtime;
 }
 
-SPVM_RUNTIME* SPVM_API_RUNTIME_new_object() {
+SPVM_RUNTIME* SPVM_API_RUNTIME_new_instance() {
   SPVM_RUNTIME* runtime = SPVM_RUNTIME_new();
   
   return runtime;
 }
 
-void SPVM_API_RUNTIME_free_object(SPVM_RUNTIME* runtime) {
+void SPVM_API_RUNTIME_free_instance(SPVM_RUNTIME* runtime) {
 
   SPVM_RUNTIME_free(runtime);
 }
@@ -1058,3 +1060,16 @@ int32_t SPVM_API_RUNTIME_can_assign(SPVM_RUNTIME* runtime, SPVM_RUNTIME_BASIC_TY
   return isa;
 }
 
+void SPVM_API_PRECOMPILE_build_precompile_module_source(SPVM_RUNTIME* runtime, SPVM_STRING_BUFFER* string_buffer, const char* module_name) {
+  SPVM_PRECOMPILE* precompile = SPVM_PRECOMPILE_new(precompile);
+  SPVM_PRECOMPILE_set_runtime(precompile, runtime);
+  SPVM_PRECOMPILE_build_module_source(precompile, string_buffer, module_name);
+  SPVM_PRECOMPILE_free(precompile);
+}
+
+void SPVM_API_PRECOMPILE_build_precompile_method_source(SPVM_RUNTIME* runtime, SPVM_STRING_BUFFER* string_buffer, const char* module_name, const char* method_name) {
+  SPVM_PRECOMPILE* precompile = SPVM_PRECOMPILE_new(precompile);
+  SPVM_PRECOMPILE_set_runtime(precompile, runtime);
+  SPVM_PRECOMPILE_build_method_source(precompile, string_buffer, module_name, method_name);
+  SPVM_PRECOMPILE_free(precompile);
+}
