@@ -36,6 +36,7 @@
 #include "spvm_call_method.h"
 #include "spvm_var.h"
 #include "spvm_string.h"
+#include "spvm_module_file.h"
 
 #include "spvm_runtime_basic_type.h"
 #include "spvm_runtime_class_var.h"
@@ -61,16 +62,21 @@ SPVM_COMPILER* SPVM_COMPILER_new() {
   compiler->include_dirs = SPVM_LIST_new_list_permanent(compiler->allocator, 0);
   compiler->basic_types = SPVM_LIST_new_list_permanent(compiler->allocator, 0);
   compiler->basic_type_symtable = SPVM_HASH_new_hash_permanent(compiler->allocator, 0);
-  compiler->module_source_symtable = SPVM_HASH_new_hash_permanent(compiler->allocator, 0);
-  compiler->if_require_not_found_basic_type_name_symtable = SPVM_HASH_new_hash_permanent(compiler->allocator, 0);
+  compiler->module_file_symtable = SPVM_HASH_new_hash_permanent(compiler->allocator, 0);
+  compiler->if_require_not_found_module_name_symtable = SPVM_HASH_new_hash_permanent(compiler->allocator, 0);
   
   return compiler;
 }
 
-void SPVM_COMPILER_add_source(SPVM_COMPILER* compiler, const char* basic_type_name, const char* source, int32_t length) {
-  SPVM_STRING_BUFFER* source_buffer = SPVM_STRING_BUFFER_new(compiler->allocator, length, SPVM_ALLOCATOR_C_ALLOC_TYPE_PERMANENT);
-  SPVM_STRING_BUFFER_add_len(source_buffer, (char*)source, strlen(source));
-  SPVM_HASH_set(compiler->module_source_symtable, basic_type_name, strlen(basic_type_name), (void*)source_buffer);
+SPVM_MODULE_FILE* SPVM_COMPILER_get_module_file(SPVM_COMPILER* compiler, const char* module_name) {
+  SPVM_MODULE_FILE* module_file = SPVM_HASH_get(compiler->module_file_symtable, module_name, strlen(module_name));
+  
+  return module_file;
+}
+
+void SPVM_COMPILER_add_module_file(SPVM_COMPILER* compiler, const char* module_name, SPVM_MODULE_FILE* module_file) {
+  
+  SPVM_HASH_set(compiler->module_file_symtable, module_name, strlen(module_name), (void*)module_file);
 }
 
 void SPVM_COMPILER_add_basic_type_core(SPVM_COMPILER* compiler, int32_t basic_type_id, int32_t basic_type_category) {
@@ -184,88 +190,124 @@ int32_t SPVM_COMPILER_compile(SPVM_COMPILER* compiler, const char* basic_type_na
     // Add basic types
     SPVM_COMPILER_add_basic_types(compiler);
     
-    // Add Bool source
+    // Add Bool module file
     {
-      const char* basic_type_name = "Bool";
-      const char* source = "class Bool {\n  INIT {\n    $TRUE = new Bool;\n    $TRUE->{value} = 1;\n    $FALSE = new Bool;\n    $FALSE->{value} = 0;\n  }\n  \n  our $TRUE : ro Bool;\n  our $FALSE : ro Bool;\n  has value : ro int;\n}";
-      SPVM_COMPILER_add_source(compiler, basic_type_name, source, strlen(source));
+      SPVM_MODULE_FILE* module_file = SPVM_MODULE_FILE_new(compiler);
+      module_file->module_name = "Bool";
+      module_file->rel_file = "Bool.spvm";
+      module_file->content = "class Bool {\n  INIT {\n    $TRUE = new Bool;\n    $TRUE->{value} = 1;\n    $FALSE = new Bool;\n    $FALSE->{value} = 0;\n  }\n  \n  our $TRUE : ro Bool;\n  our $FALSE : ro Bool;\n  has value : ro int;\n}";
+      module_file->content_length = strlen(module_file->content);
+      SPVM_COMPILER_add_module_file(compiler, module_file->module_name, module_file);
     }
     
-    // Add Error source
+    // Add Error module file
     {
-      const char* basic_type_name = "Error";
-      const char* source = "class Error;";
-      SPVM_COMPILER_add_source(compiler, basic_type_name, source, strlen(source));
+      SPVM_MODULE_FILE* module_file = SPVM_MODULE_FILE_new(compiler);
+      module_file->module_name = "Error";
+      module_file->rel_file = "Error.spvm";
+      module_file->content = "class Error;";
+      module_file->content_length = strlen(module_file->content);
+      SPVM_COMPILER_add_module_file(compiler, module_file->module_name, module_file);
     }
     
-    // Add Error::System source
+    // Add Error::System module file
     {
-      const char* basic_type_name = "Error::System";
-      const char* source = "class Error::System extends Error;";
-      SPVM_COMPILER_add_source(compiler, basic_type_name, source, strlen(source));
+      SPVM_MODULE_FILE* module_file = SPVM_MODULE_FILE_new(compiler);
+      module_file->module_name = "Error::System";
+      module_file->rel_file = "Error/System.spvm";
+      module_file->content = "class Error::System extends Error;";
+      module_file->content_length = strlen(module_file->content);
+      SPVM_COMPILER_add_module_file(compiler, module_file->module_name, module_file);
     }
     
-    // Add Error::NotSupported source
+    // Add Error::NotSupported module file
     {
-      const char* basic_type_name = "Error::NotSupported";
-      const char* source = "class Error::NotSupported extends Error;";
-      SPVM_COMPILER_add_source(compiler, basic_type_name, source, strlen(source));
+      SPVM_MODULE_FILE* module_file = SPVM_MODULE_FILE_new(compiler);
+      module_file->module_name = "Error::NotSupported";
+      module_file->rel_file = "Error/NotSupported.spvm";
+      module_file->content = "class Error::NotSupported extends Error;";
+      module_file->content_length = strlen(module_file->content);
+      SPVM_COMPILER_add_module_file(compiler, module_file->module_name, module_file);
     }
     
-    // Add Byte source
+    // Add Byte module file
     {
-      const char* basic_type_name = "Byte";
-      const char* source = "class Byte {\n  has value : ro byte;\n  static method new : Byte ($value : int) {\n    my $self = new Byte;\n    $self->{value} = (byte)$value;\n    return $self;\n  }\n}";
-      SPVM_COMPILER_add_source(compiler, basic_type_name, source, strlen(source));
+      SPVM_MODULE_FILE* module_file = SPVM_MODULE_FILE_new(compiler);
+      module_file->module_name = "Byte";
+      module_file->rel_file = "Byte.spvm";
+      module_file->content = "class Byte {\n  has value : ro byte;\n  static method new : Byte ($value : int) {\n    my $self = new Byte;\n    $self->{value} = (byte)$value;\n    return $self;\n  }\n}";
+      module_file->content_length = strlen(module_file->content);
+      SPVM_COMPILER_add_module_file(compiler, module_file->module_name, module_file);
     }
     
-    // Add Short source
+    // Add Short module file
     {
-      const char* basic_type_name = "Short";
-      const char* source = "class Short {\n  has value : ro short;\n  static method new : Short ($value : int) {\n    my $self = new Short;\n    $self->{value} = (short)$value;\n    return $self;\n  }\n}";
-      SPVM_COMPILER_add_source(compiler, basic_type_name, source, strlen(source));
+      SPVM_MODULE_FILE* module_file = SPVM_MODULE_FILE_new(compiler);
+      module_file->module_name = "Short";
+      module_file->rel_file = "Short.spvm";
+      module_file->content = "class Short {\n  has value : ro short;\n  static method new : Short ($value : int) {\n    my $self = new Short;\n    $self->{value} = (short)$value;\n    return $self;\n  }\n}";
+      module_file->content_length = strlen(module_file->content);
+      SPVM_COMPILER_add_module_file(compiler, module_file->module_name, module_file);
     }
     
-    // Add Int source
+    // Add Int module file
     {
-      const char* basic_type_name = "Int";
-      const char* source = "class Int {\n  has value : ro int;\n  static method new : Int ($value : int) {\n    my $self = new Int;\n    $self->{value} = $value;\n    return $self;\n  }\n}";
-      SPVM_COMPILER_add_source(compiler, basic_type_name, source, strlen(source));
+      SPVM_MODULE_FILE* module_file = SPVM_MODULE_FILE_new(compiler);
+      module_file->module_name = "Int";
+      module_file->rel_file = "Int.spvm";
+      module_file->content = "class Int {\n  has value : ro int;\n  static method new : Int ($value : int) {\n    my $self = new Int;\n    $self->{value} = $value;\n    return $self;\n  }\n}";
+      module_file->content_length = strlen(module_file->content);
+      SPVM_COMPILER_add_module_file(compiler, module_file->module_name, module_file);
     }
     
-    // Add Long source
+    // Add Long module file
     {
-      const char* basic_type_name = "Long";
-      const char* source = "class Long {\n  has value : ro long;\n  static method new : Long ($value : long) {\n    my $self = new Long;\n    $self->{value} = $value;\n    return $self;\n  }\n}";
-      SPVM_COMPILER_add_source(compiler, basic_type_name, source, strlen(source));
+      SPVM_MODULE_FILE* module_file = SPVM_MODULE_FILE_new(compiler);
+      module_file->module_name = "Long";
+      module_file->rel_file = "Long.spvm";
+      module_file->content = "class Long {\n  has value : ro long;\n  static method new : Long ($value : long) {\n    my $self = new Long;\n    $self->{value} = $value;\n    return $self;\n  }\n}";
+      module_file->content_length = strlen(module_file->content);
+      SPVM_COMPILER_add_module_file(compiler, module_file->module_name, module_file);
     }
     
-    // Add Float source
+    // Add Float module file
     {
-      const char* basic_type_name = "Float";
-      const char* source = "class Float {\n  has value : ro float;\n  static method new : Float ($value : float) {\n    my $self = new Float;\n    $self->{value} = $value;\n    return $self;\n  }\n}";
-      SPVM_COMPILER_add_source(compiler, basic_type_name, source, strlen(source));
+      SPVM_MODULE_FILE* module_file = SPVM_MODULE_FILE_new(compiler);
+      module_file->module_name = "Float";
+      module_file->rel_file = "Float.spvm";
+      module_file->content = "class Float {\n  has value : ro float;\n  static method new : Float ($value : float) {\n    my $self = new Float;\n    $self->{value} = $value;\n    return $self;\n  }\n}";
+      module_file->content_length = strlen(module_file->content);
+      SPVM_COMPILER_add_module_file(compiler, module_file->module_name, module_file);
     }
     
-    // Add Double source
+    // Add Double module file
     {
-      const char* basic_type_name = "Double";
-      const char* source = "class Double {\n  has value : ro double;\n  static method new : Double ($value : double) {\n    my $self = new Double;\n    $self->{value} = $value;\n    return $self;\n  }\n}";
-      SPVM_COMPILER_add_source(compiler, basic_type_name, source, strlen(source));
+      SPVM_MODULE_FILE* module_file = SPVM_MODULE_FILE_new(compiler);
+      module_file->module_name = "Double";
+      module_file->rel_file = "Double.spvm";
+      module_file->content = "class Double {\n  has value : ro double;\n  static method new : Double ($value : double) {\n    my $self = new Double;\n    $self->{value} = $value;\n    return $self;\n  }\n}";
+      module_file->content_length = strlen(module_file->content);
+      SPVM_COMPILER_add_module_file(compiler, module_file->module_name, module_file);
     }
     
-    // Add CommandInfo source
+    // Add CommandInfo module file
     {
-      const char* basic_type_name = "CommandInfo";
-      const char* source = "class CommandInfo {\n  our $PROGRAM_NAME : ro string;\n  our $ARGV : ro string[];\n  our $BASE_TIME : ro long;\n  }";
-      SPVM_COMPILER_add_source(compiler, basic_type_name, source, strlen(source));
+      SPVM_MODULE_FILE* module_file = SPVM_MODULE_FILE_new(compiler);
+      module_file->module_name = "CommandInfo";
+      module_file->rel_file = "CommandInfo.spvm";
+      module_file->content = "class CommandInfo {\n  our $PROGRAM_NAME : ro string;\n  our $ARGV : ro string[];\n  our $BASE_TIME : ro long;\n  }";
+      module_file->content_length = strlen(module_file->content);
+      SPVM_COMPILER_add_module_file(compiler, module_file->module_name, module_file);
     }
     
-    // Add Address source
+    // Add Address module file
     {
-      const char* basic_type_name = "Address";
-      const char* source = "class Address : pointer {\n  static method new : Address () {\n    my $self = new Address;\n    return $self;\n  }\n}";
-      SPVM_COMPILER_add_source(compiler, basic_type_name, source, strlen(source));
+      SPVM_MODULE_FILE* module_file = SPVM_MODULE_FILE_new(compiler);
+      module_file->module_name = "Address";
+      module_file->rel_file = "Address.spvm";
+      module_file->content = "class Address : pointer {\n  static method new : Address () {\n    my $self = new Address;\n    return $self;\n  }\n}";
+      module_file->content_length = strlen(module_file->content);
+      SPVM_COMPILER_add_module_file(compiler, module_file->module_name, module_file);
     }
   }
   
@@ -698,7 +740,7 @@ int32_t* SPVM_COMPILER_create_runtime_codes(SPVM_COMPILER* compiler, SPVM_ALLOCA
     int32_t string_pool_base = 0;
     for (int32_t basic_type_id = 0; basic_type_id < compiler->basic_types->length; basic_type_id++) {
       SPVM_BASIC_TYPE* basic_type = SPVM_LIST_get(compiler->basic_types, basic_type_id);
-      memcpy((char*)((intptr_t)runtime_codes_ptr + string_pool_base), basic_type->string_pool->value, basic_type->string_pool->length);
+      memcpy((char*)((intptr_t)runtime_codes_ptr + string_pool_base), basic_type->string_pool->string, basic_type->string_pool->length);
       string_pool_base += basic_type->string_pool->length;
     }
   }
@@ -867,11 +909,10 @@ int32_t* SPVM_COMPILER_create_runtime_codes(SPVM_COMPILER* compiler, SPVM_ALLOCA
     for (int32_t method_index = 0; method_index < basic_type->methods->length; method_index++) {
       SPVM_METHOD* method = SPVM_LIST_get(basic_type->methods, method_index);
       SPVM_OPCODE_LIST* opcode_list = method->opcode_list;
-      memcpy(runtime_codes_ptr + opcodes_runtime_codes_base, opcode_list->values, sizeof(SPVM_OPCODE) * opcode_list->length);
-      opcodes_runtime_codes_base += (sizeof(SPVM_OPCODE) / sizeof(int32_t)) * opcode_list->length;
+      memcpy(runtime_codes_ptr, opcode_list->values, sizeof(SPVM_OPCODE) * opcode_list->length);
+      runtime_codes_ptr += (sizeof(SPVM_OPCODE) / sizeof(int32_t)) * opcode_list->length;
     }
   }
-  runtime_codes_ptr += (sizeof(SPVM_OPCODE) / sizeof(int32_t)) * opcodes_length;
   
   // anon_basic_types_length
   int32_t anon_basic_types_length = SPVM_COMPILER_get_anon_basic_types_length(compiler);
