@@ -24,7 +24,7 @@
 #include "spvm_opcode.h"
 #include "spvm_class_var.h"
 #include "spvm_class_var_access.h"
-#include "spvm_opcode_array.h"
+#include "spvm_opcode_list.h"
 #include "spvm_block.h"
 #include "spvm_basic_type.h"
 #include "spvm_field_access.h"
@@ -210,7 +210,7 @@ void SPVM_DUMPER_dump_basic_types(SPVM_COMPILER* compiler, SPVM_LIST* basic_type
   }
 }
 
-void SPVM_DUMPER_dump_basic_types_opcode_array(SPVM_COMPILER* compiler, SPVM_LIST* basic_types) {
+void SPVM_DUMPER_dump_basic_types_opcode_list(SPVM_COMPILER* compiler, SPVM_LIST* basic_types) {
   for (int32_t i = 0; i < basic_types->length; i++) {
     fprintf(stderr, "basic_types[%" PRId32 "]\n", i);
     SPVM_BASIC_TYPE* basic_type = SPVM_LIST_get(basic_types, i);
@@ -227,30 +227,23 @@ void SPVM_DUMPER_dump_basic_types_opcode_array(SPVM_COMPILER* compiler, SPVM_LIS
       for (j = 0; j < basic_type->methods->length; j++) {
         SPVM_METHOD* method = SPVM_LIST_get(basic_type->methods, j);
         fprintf(stderr, "  methods[%" PRId32 "]\n", j);
-        SPVM_DUMPER_dump_method_opcode_array(compiler, method);
+        SPVM_DUMPER_dump_method_opcode_list(compiler, method);
       }
     }
   }
 }
 
-void SPVM_DUMPER_dump_opcode_array(SPVM_COMPILER* compiler, SPVM_OPCODE_ARRAY* opcode_array, int32_t start_pos, int32_t length) {
-  (void)compiler;
+void SPVM_DUMPER_dump_opcode_list(SPVM_COMPILER* compiler, SPVM_OPCODE_LIST* opcode_list) {
   
-  int32_t end_pos = start_pos + length - 1;
-  
-  {
-    int32_t i;
-    for (i = start_pos; i <= end_pos; i++) {
-      
-      SPVM_OPCODE opcode = opcode_array->values[i];
-      fprintf(stderr, "        [%" PRId32 "] %-20s", i, (SPVM_OPCODE_C_ID_NAMES())[opcode.id]);
-      fprintf(stderr, " %d %d %d %d\n", opcode.operand0, opcode.operand1, opcode.operand2, opcode.operand3);
-    }
+  for (int32_t i = 0; i <= opcode_list->length; i++) {
+    
+    SPVM_OPCODE opcode = opcode_list->values[i];
+    fprintf(stderr, "        [%" PRId32 "] %-20s", i, (SPVM_OPCODE_C_ID_NAMES())[opcode.id]);
+    fprintf(stderr, " %d %d %d %d\n", opcode.operand0, opcode.operand1, opcode.operand2, opcode.operand3);
   }
 }
 
 void SPVM_DUMPER_dump_constant(SPVM_COMPILER* compiler, SPVM_CONSTANT* constant) {
-  (void)compiler;
   
   if (constant->type->dimension == 0) {
     switch(constant->type->basic_type->id) {
@@ -282,7 +275,6 @@ void SPVM_DUMPER_dump_constant(SPVM_COMPILER* compiler, SPVM_CONSTANT* constant)
 }
 
 void SPVM_DUMPER_dump_method(SPVM_COMPILER* compiler, SPVM_METHOD* method) {
-  (void)compiler;
   
   if (method) {
     
@@ -320,8 +312,7 @@ void SPVM_DUMPER_dump_method(SPVM_COMPILER* compiler, SPVM_METHOD* method) {
   }
 }
 
-void SPVM_DUMPER_dump_method_opcode_array(SPVM_COMPILER* compiler, SPVM_METHOD* method) {
-  (void)compiler;
+void SPVM_DUMPER_dump_method_opcode_list(SPVM_COMPILER* compiler, SPVM_METHOD* method) {
   
   if (method) {
     fprintf(stderr, "      name => \"%s\"\n", method->name);
@@ -337,8 +328,8 @@ void SPVM_DUMPER_dump_method_opcode_array(SPVM_COMPILER* compiler, SPVM_METHOD*
         }
       }
       
-      fprintf(stderr, "      opcode_array\n");
-      SPVM_DUMPER_dump_opcode_array(compiler, compiler->opcode_array, method->opcodes_base_address_id, method->opcodes_length);
+      fprintf(stderr, "      opcode_list\n");
+      SPVM_DUMPER_dump_opcode_list(compiler, method->opcode_list);
     }
   }
   else {
@@ -347,7 +338,6 @@ void SPVM_DUMPER_dump_method_opcode_array(SPVM_COMPILER* compiler, SPVM_METHOD*
 }
 
 void SPVM_DUMPER_dump_field(SPVM_COMPILER* compiler, SPVM_FIELD* field) {
-  (void)compiler;
   
   if (field) {
     fprintf(stderr, "      name => \"%s\"\n", field->name);
@@ -367,7 +357,6 @@ void SPVM_DUMPER_dump_field(SPVM_COMPILER* compiler, SPVM_FIELD* field) {
 
 
 void SPVM_DUMPER_dump_var_decl(SPVM_COMPILER* compiler, SPVM_VAR_DECL* var_decl) {
-  (void)compiler;
   
   if (var_decl) {
     fprintf(stderr, "\n");
