@@ -4,25 +4,28 @@ SPVM::Document::NativeAPI::Runtime - SPVM Runtime Native APIs
 
 =head1 Usage
 
-  // New a runtime
-  void* runtime = env->api->runtime->new_object();
+  // Runtime Native API
+  SSPVM_ENV_RUNTIME* runtime_api = env->api->runtime;
+  
+  // New a runtime object
+  SPVM_ENV_RUNTIME* runtime = runtime_api->new_instance();
   
   // Build the runtime
   env->api->runtime->build(runtime, runtime_codes);
   
-  // Free a runtime
-  env->api->runtime->free_object(runtime);
+  // Free a runtime object
+  env->api->runtime->free_instance(runtime);
 
 =head1 Description
 
-SPVM runtime native APIs are the public APIs to manipulate the runtime information.
+SPVM Runtime Native APIs are the APIs to manipulate runtime information.
 
-=head1 Ids Of Runtime Native APIs
+=head1 IDs of Runtime Native APIs
 
 Runtime native APIs have its IDs.
 
-  0  new_object
-  1  free_object
+  0  new_instance
+  1  free_instance
   2  get_opcodes
   3  reserved3
   4  get_runtime_codes
@@ -159,13 +162,13 @@ Runtime native APIs have its IDs.
 
 =head1 Runtime Native APIs
 
-=head2 new_object
+=head2 new_instance
 
-  void* (*new_object)();
+  void* (*new_instance)(void);
 
-=head2 free_object
+=head2 free_instance
 
-  void (*free_object)(void* runtime);
+  void (*free_instance)(void* runtime);
 
 =head2 get_opcodes
 
